

Default configs:

SHOW_LOGIN = True
SHOW_LAST_FIRST_NAME = True
SHOW_CONTRACTOR_TYPE = True
SHOW_ADDRESS = True
SHOW_BILLING_ADDRESS = True
SHOW_NUMBER = True
NUMBER_IS_REQUIRED = True
SHOW_TAX_NUMBER = True
TAX_NUMBER_IS_REQUIRED = True
SHOW_ID_CARD_FIELDS = True
SHOW_NAME_LEGAL = True
NAME_LEGAL_IS_REQUIRED = False
SHOW_ACCOUNTING_NUMBER = True
DEFAULT_COUNTRY = UKR
